/*
 * Copyright (C) 2000-2005 ASANO Masahiro
 */

#include <unistd.h>
#include "crash.h"

void
load_pgd(addr)
	addr_t addr;
{
}

addr_t
translate_addr(addr, count, errmsg)
	addr_t addr;
	addr_t *count;
	const char *errmsg;
{
	if (addr < kmem_low) {
		/* user space, not work... */
		THROWF("Error: V-P translation error(low): %lx", addr);
	} else if (addr >= (high_memory > kmem_high? high_memory: kmem_high)) {
		/* not work... */
		THROWF("Error: V-P translation error(high): %lx", addr);
	}
	/* global address */
	return _PA(addr);
}
